# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_portfolio_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_portfolio_rpc.proto\x12\x17injective_portfolio_rpc\"2\n\x17\x41\x63\x63ountPortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\"Q\n\x18\x41\x63\x63ountPortfolioResponse\x12\x35\n\tportfolio\x18\x01 \x01(\x0b\x32\".injective_portfolio_rpc.Portfolio\"\xe6\x01\n\tPortfolio\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x34\n\rbank_balances\x18\x02 \x03(\x0b\x32\x1d.injective_portfolio_rpc.Coin\x12\x41\n\x0bsubaccounts\x18\x03 \x03(\x0b\x32,.injective_portfolio_rpc.SubaccountBalanceV2\x12G\n\x13positions_with_upnl\x18\x04 \x03(\x0b\x32*.injective_portfolio_rpc.PositionsWithUPNL\"%\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\t\"x\n\x13SubaccountBalanceV2\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12;\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32*.injective_portfolio_rpc.SubaccountDeposit\"E\n\x11SubaccountDeposit\x12\x15\n\rtotal_balance\x18\x01 \x01(\t\x12\x19\n\x11\x61vailable_balance\x18\x02 \x01(\t\"j\n\x11PositionsWithUPNL\x12=\n\x08position\x18\x01 \x01(\x0b\x32+.injective_portfolio_rpc.DerivativePosition\x12\x16\n\x0eunrealized_pnl\x18\x02 \x01(\t\"\x97\x02\n\x12\x44\x65rivativePosition\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rsubaccount_id\x18\x03 \x01(\t\x12\x11\n\tdirection\x18\x04 \x01(\t\x12\x10\n\x08quantity\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntry_price\x18\x06 \x01(\t\x12\x0e\n\x06margin\x18\x07 \x01(\t\x12\x19\n\x11liquidation_price\x18\x08 \x01(\t\x12\x12\n\nmark_price\x18\t \x01(\t\x12&\n\x1e\x61ggregate_reduce_only_quantity\x18\x0b \x01(\t\x12\x12\n\nupdated_at\x18\x0c \x01(\x12\x12\x12\n\ncreated_at\x18\r \x01(\x12\"]\n\x1dStreamAccountPortfolioRequest\x12\x17\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\"d\n\x1eStreamAccountPortfolioResponse\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x0e\n\x06\x61mount\x18\x03 \x01(\t\x12\x15\n\rsubaccount_id\x18\x04 \x01(\t2\x9e\x02\n\x15InjectivePortfolioRPC\x12w\n\x10\x41\x63\x63ountPortfolio\x12\x30.injective_portfolio_rpc.AccountPortfolioRequest\x1a\x31.injective_portfolio_rpc.AccountPortfolioResponse\x12\x8b\x01\n\x16StreamAccountPortfolio\x12\x36.injective_portfolio_rpc.StreamAccountPortfolioRequest\x1a\x37.injective_portfolio_rpc.StreamAccountPortfolioResponse0\x01\x42\x1cZ\x1a/injective_portfolio_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_portfolio_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\032/injective_portfolio_rpcpb'
  _ACCOUNTPORTFOLIOREQUEST._serialized_start=67
  _ACCOUNTPORTFOLIOREQUEST._serialized_end=117
  _ACCOUNTPORTFOLIORESPONSE._serialized_start=119
  _ACCOUNTPORTFOLIORESPONSE._serialized_end=200
  _PORTFOLIO._serialized_start=203
  _PORTFOLIO._serialized_end=433
  _COIN._serialized_start=435
  _COIN._serialized_end=472
  _SUBACCOUNTBALANCEV2._serialized_start=474
  _SUBACCOUNTBALANCEV2._serialized_end=594
  _SUBACCOUNTDEPOSIT._serialized_start=596
  _SUBACCOUNTDEPOSIT._serialized_end=665
  _POSITIONSWITHUPNL._serialized_start=667
  _POSITIONSWITHUPNL._serialized_end=773
  _DERIVATIVEPOSITION._serialized_start=776
  _DERIVATIVEPOSITION._serialized_end=1055
  _STREAMACCOUNTPORTFOLIOREQUEST._serialized_start=1057
  _STREAMACCOUNTPORTFOLIOREQUEST._serialized_end=1150
  _STREAMACCOUNTPORTFOLIORESPONSE._serialized_start=1152
  _STREAMACCOUNTPORTFOLIORESPONSE._serialized_end=1252
  _INJECTIVEPORTFOLIORPC._serialized_start=1255
  _INJECTIVEPORTFOLIORPC._serialized_end=1541
# @@protoc_insertion_point(module_scope)
