# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/ocr/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.ocr.v1beta1 import ocr_pb2 as injective_dot_ocr_dot_v1beta1_dot_ocr__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/ocr/v1beta1/tx.proto\x12\x15injective.ocr.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1finjective/ocr/v1beta1/ocr.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\\\n\rMsgCreateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x31\n\x06\x63onfig\x18\x02 \x01(\x0b\x32!.injective.ocr.v1beta1.FeedConfig:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgCreateFeedResponse\"\xbd\x02\n\rMsgUpdateFeed\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x0f\n\x07signers\x18\x03 \x03(\t\x12\x14\n\x0ctransmitters\x18\x04 \x03(\t\x12L\n\x14link_per_observation\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12M\n\x15link_per_transmission\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x01\x12\x12\n\nlink_denom\x18\x07 \x01(\t\x12\x12\n\nfeed_admin\x18\x08 \x01(\t\x12\x15\n\rbilling_admin\x18\t \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUpdateFeedResponse\"\xc9\x01\n\x0bMsgTransmit\x12\x13\n\x0btransmitter\x18\x01 \x01(\t\x12\x15\n\rconfig_digest\x18\x02 \x01(\x0c\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\r\n\x05\x65poch\x18\x04 \x01(\x04\x12\r\n\x05round\x18\x05 \x01(\x04\x12\x12\n\nextra_hash\x18\x06 \x01(\x0c\x12-\n\x06report\x18\x07 \x01(\x0b\x32\x1d.injective.ocr.v1beta1.Report\x12\x12\n\nsignatures\x18\x08 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x15\n\x13MsgTransmitResponse\"s\n\x15MsgFundFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1f\n\x1dMsgFundFeedRewardPoolResponse\"w\n\x19MsgWithdrawFeedRewardPool\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"#\n!MsgWithdrawFeedRewardPoolResponse\"_\n\x0cMsgSetPayees\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x02 \x01(\t\x12\x14\n\x0ctransmitters\x18\x03 \x03(\t\x12\x0e\n\x06payees\x18\x04 \x03(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x16\n\x14MsgSetPayeesResponse\"h\n\x14MsgTransferPayeeship\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t\x12\x10\n\x08proposed\x18\x04 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgTransferPayeeshipResponse\"S\n\x12MsgAcceptPayeeship\x12\r\n\x05payee\x18\x01 \x01(\t\x12\x13\n\x0btransmitter\x18\x02 \x01(\t\x12\x0f\n\x07\x66\x65\x65\x64_id\x18\x03 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgAcceptPayeeshipResponse2\xed\x06\n\x03Msg\x12`\n\nCreateFeed\x12$.injective.ocr.v1beta1.MsgCreateFeed\x1a,.injective.ocr.v1beta1.MsgCreateFeedResponse\x12`\n\nUpdateFeed\x12$.injective.ocr.v1beta1.MsgUpdateFeed\x1a,.injective.ocr.v1beta1.MsgUpdateFeedResponse\x12Z\n\x08Transmit\x12\".injective.ocr.v1beta1.MsgTransmit\x1a*.injective.ocr.v1beta1.MsgTransmitResponse\x12x\n\x12\x46undFeedRewardPool\x12,.injective.ocr.v1beta1.MsgFundFeedRewardPool\x1a\x34.injective.ocr.v1beta1.MsgFundFeedRewardPoolResponse\x12\x84\x01\n\x16WithdrawFeedRewardPool\x12\x30.injective.ocr.v1beta1.MsgWithdrawFeedRewardPool\x1a\x38.injective.ocr.v1beta1.MsgWithdrawFeedRewardPoolResponse\x12]\n\tSetPayees\x12#.injective.ocr.v1beta1.MsgSetPayees\x1a+.injective.ocr.v1beta1.MsgSetPayeesResponse\x12u\n\x11TransferPayeeship\x12+.injective.ocr.v1beta1.MsgTransferPayeeship\x1a\x33.injective.ocr.v1beta1.MsgTransferPayeeshipResponse\x12o\n\x0f\x41\x63\x63\x65ptPayeeship\x12).injective.ocr.v1beta1.MsgAcceptPayeeship\x1a\x31.injective.ocr.v1beta1.MsgAcceptPayeeshipResponseBKZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.ocr.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/ocr/types'
  _MSGCREATEFEED._options = None
  _MSGCREATEFEED._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGUPDATEFEED.fields_by_name['link_per_observation']._options = None
  _MSGUPDATEFEED.fields_by_name['link_per_observation']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001'
  _MSGUPDATEFEED.fields_by_name['link_per_transmission']._options = None
  _MSGUPDATEFEED.fields_by_name['link_per_transmission']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\001'
  _MSGUPDATEFEED._options = None
  _MSGUPDATEFEED._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTRANSMIT._options = None
  _MSGTRANSMIT._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGFUNDFEEDREWARDPOOL.fields_by_name['amount']._options = None
  _MSGFUNDFEEDREWARDPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGFUNDFEEDREWARDPOOL._options = None
  _MSGFUNDFEEDREWARDPOOL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount']._options = None
  _MSGWITHDRAWFEEDREWARDPOOL.fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _MSGWITHDRAWFEEDREWARDPOOL._options = None
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGSETPAYEES._options = None
  _MSGSETPAYEES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGTRANSFERPAYEESHIP._options = None
  _MSGTRANSFERPAYEESHIP._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGACCEPTPAYEESHIP._options = None
  _MSGACCEPTPAYEESHIP._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGCREATEFEED._serialized_start=144
  _MSGCREATEFEED._serialized_end=236
  _MSGCREATEFEEDRESPONSE._serialized_start=238
  _MSGCREATEFEEDRESPONSE._serialized_end=261
  _MSGUPDATEFEED._serialized_start=264
  _MSGUPDATEFEED._serialized_end=581
  _MSGUPDATEFEEDRESPONSE._serialized_start=583
  _MSGUPDATEFEEDRESPONSE._serialized_end=606
  _MSGTRANSMIT._serialized_start=609
  _MSGTRANSMIT._serialized_end=810
  _MSGTRANSMITRESPONSE._serialized_start=812
  _MSGTRANSMITRESPONSE._serialized_end=833
  _MSGFUNDFEEDREWARDPOOL._serialized_start=835
  _MSGFUNDFEEDREWARDPOOL._serialized_end=950
  _MSGFUNDFEEDREWARDPOOLRESPONSE._serialized_start=952
  _MSGFUNDFEEDREWARDPOOLRESPONSE._serialized_end=983
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_start=985
  _MSGWITHDRAWFEEDREWARDPOOL._serialized_end=1104
  _MSGWITHDRAWFEEDREWARDPOOLRESPONSE._serialized_start=1106
  _MSGWITHDRAWFEEDREWARDPOOLRESPONSE._serialized_end=1141
  _MSGSETPAYEES._serialized_start=1143
  _MSGSETPAYEES._serialized_end=1238
  _MSGSETPAYEESRESPONSE._serialized_start=1240
  _MSGSETPAYEESRESPONSE._serialized_end=1262
  _MSGTRANSFERPAYEESHIP._serialized_start=1264
  _MSGTRANSFERPAYEESHIP._serialized_end=1368
  _MSGTRANSFERPAYEESHIPRESPONSE._serialized_start=1370
  _MSGTRANSFERPAYEESHIPRESPONSE._serialized_end=1400
  _MSGACCEPTPAYEESHIP._serialized_start=1402
  _MSGACCEPTPAYEESHIP._serialized_end=1485
  _MSGACCEPTPAYEESHIPRESPONSE._serialized_start=1487
  _MSGACCEPTPAYEESHIPRESPONSE._serialized_end=1515
  _MSG._serialized_start=1518
  _MSG._serialized_end=2395
# @@protoc_insertion_point(module_scope)
