# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/exchange.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/exchange/v1beta1/exchange.proto\x12\x1ainjective.exchange.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\xf0\x0e\n\x06Params\x12H\n\x1fspot_market_instant_listing_fee\x18\x01 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12N\n%derivative_market_instant_listing_fee\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12S\n\x1b\x64\x65\x66\x61ult_spot_maker_fee_rate\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12S\n\x1b\x64\x65\x66\x61ult_spot_taker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n!default_derivative_maker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n!default_derivative_taker_fee_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12T\n\x1c\x64\x65\x66\x61ult_initial_margin_ratio\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12X\n default_maintenance_margin_ratio\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12 \n\x18\x64\x65\x66\x61ult_funding_interval\x18\t \x01(\x03\x12\x18\n\x10\x66unding_multiple\x18\n \x01(\x03\x12N\n\x16relayer_fee_share_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12W\n\x1f\x64\x65\x66\x61ult_hourly_funding_rate_cap\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12T\n\x1c\x64\x65\x66\x61ult_hourly_interest_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\'\n\x1fmax_derivative_order_side_count\x18\x0e \x01(\r\x12_\n\'inj_reward_staked_requirement_threshold\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12(\n trading_rewards_vesting_duration\x18\x10 \x01(\x03\x12T\n\x1cliquidator_reward_share_rate\x18\x11 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12R\n)binary_options_market_instant_listing_fee\x18\x12 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00\x12\x62\n atomic_market_order_access_level\x18\x13 \x01(\x0e\x32\x38.injective.exchange.v1beta1.AtomicMarketOrderAccessLevel\x12_\n\'spot_atomic_market_order_fee_multiplier\x18\x14 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x65\n-derivative_atomic_market_order_fee_multiplier\x18\x15 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12i\n1binary_options_atomic_market_order_fee_multiplier\x18\x16 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Q\n\x19minimal_protocol_fee_rate\x18\x17 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x33\n+is_instant_derivative_market_launch_enabled\x18\x18 \x01(\x08:\x04\xe8\xa0\x1f\x01\"v\n\x13MarketFeeMultiplier\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x46\n\x0e\x66\x65\x65_multiplier\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\xbf\x06\n\x10\x44\x65rivativeMarket\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x13\n\x0boracle_base\x18\x02 \x01(\t\x12\x14\n\x0coracle_quote\x18\x03 \x01(\t\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x05 \x01(\r\x12\x13\n\x0bquote_denom\x18\x06 \x01(\t\x12\x11\n\tmarket_id\x18\x07 \x01(\t\x12L\n\x14initial_margin_ratio\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0emaker_fee_rate\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16relayer_fee_share_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x13\n\x0bisPerpetual\x18\r \x01(\x08\x12\x38\n\x06status\x18\x0e \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12K\n\x13min_price_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x10 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x04\x88\xa0\x1f\x00\"\xa7\x06\n\x13\x42inaryOptionsMarket\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x15\n\roracle_symbol\x18\x02 \x01(\t\x12\x17\n\x0foracle_provider\x18\x03 \x01(\t\x12\x39\n\x0boracle_type\x18\x04 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x1b\n\x13oracle_scale_factor\x18\x05 \x01(\r\x12\x1c\n\x14\x65xpiration_timestamp\x18\x06 \x01(\x03\x12\x1c\n\x14settlement_timestamp\x18\x07 \x01(\x03\x12\r\n\x05\x61\x64min\x18\x08 \x01(\t\x12\x13\n\x0bquote_denom\x18\t \x01(\t\x12\x11\n\tmarket_id\x18\n \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x0b \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x0c \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16relayer_fee_share_rate\x18\r \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x38\n\x06status\x18\x0e \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12K\n\x13min_price_tick_size\x18\x0f \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\x10 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10settlement_price\x18\x11 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01:\x04\x88\xa0\x1f\x00\"\x92\x02\n\x17\x45xpiryFuturesMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpiration_timestamp\x18\x02 \x01(\x03\x12\x1c\n\x14twap_start_timestamp\x18\x03 \x01(\x03\x12^\n&expiration_twap_start_price_cumulative\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10settlement_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x81\x02\n\x13PerpetualMarketInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12O\n\x17hourly_funding_rate_cap\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14hourly_interest_rate\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x1e\n\x16next_funding_timestamp\x18\x04 \x01(\x03\x12\x18\n\x10\x66unding_interval\x18\x05 \x01(\x03\"\xc6\x01\n\x16PerpetualMarketFunding\x12J\n\x12\x63umulative_funding\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x63umulative_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x16\n\x0elast_timestamp\x18\x03 \x01(\x03\"}\n\x1e\x44\x65rivativeMarketSettlementInfo\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12H\n\x10settlement_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\".\n\x14NextFundingTimestamp\x12\x16\n\x0enext_timestamp\x18\x01 \x01(\x03\"\x8f\x04\n\nSpotMarket\x12\x0e\n\x06ticker\x18\x01 \x01(\t\x12\x12\n\nbase_denom\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x46\n\x0emaker_fee_rate\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0etaker_fee_rate\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16relayer_fee_share_rate\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x11\n\tmarket_id\x18\x07 \x01(\t\x12\x38\n\x06status\x18\x08 \x01(\x0e\x32(.injective.exchange.v1beta1.MarketStatus\x12K\n\x13min_price_tick_size\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12N\n\x16min_quantity_tick_size\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x9b\x01\n\x07\x44\x65posit\x12I\n\x11\x61vailable_balance\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtotal_balance\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"%\n\x14SubaccountTradeNonce\x12\r\n\x05nonce\x18\x01 \x01(\r\"\xba\x01\n\tOrderInfo\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x15\n\rfee_recipient\x18\x02 \x01(\t\x12=\n\x05price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xe1\x01\n\tSpotOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\norder_info\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12\x45\n\rtrigger_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xa9\x02\n\x0eSpotLimitOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12@\n\x08\x66illable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\"\xae\x02\n\x0fSpotMarketOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x03 \x01(\x0c\x12\x39\n\norder_type\x18\x04 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xa7\x02\n\x0f\x44\x65rivativeOrder\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12?\n\norder_info\x18\x02 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x03 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xe9\x02\n\x1bSubaccountOrderbookMetadata\x12!\n\x19vanilla_limit_order_count\x18\x01 \x01(\r\x12%\n\x1dreduce_only_limit_order_count\x18\x02 \x01(\r\x12V\n\x1e\x61ggregate_reduce_only_quantity\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12R\n\x1a\x61ggregate_vanilla_quantity\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\'\n\x1fvanilla_conditional_order_count\x18\x05 \x01(\r\x12+\n#reduce_only_conditional_order_count\x18\x06 \x01(\r\"\xa8\x01\n\x0fSubaccountOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0cisReduceOnly\x18\x03 \x01(\x08\"e\n\x13SubaccountOrderData\x12:\n\x05order\x18\x01 \x01(\x0b\x32+.injective.exchange.v1beta1.SubaccountOrder\x12\x12\n\norder_hash\x18\x02 \x01(\x0c\"\xef\x02\n\x14\x44\x65rivativeLimitOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x06 \x01(\x0c\"\xf3\x02\n\x15\x44\x65rivativeMarketOrder\x12?\n\norder_info\x18\x01 \x01(\x0b\x32%.injective.exchange.v1beta1.OrderInfoB\x04\xc8\xde\x1f\x00\x12\x39\n\norder_type\x18\x02 \x01(\x0e\x32%.injective.exchange.v1beta1.OrderType\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0bmargin_hold\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rtrigger_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x12\n\norder_hash\x18\x06 \x01(\x0c\"\xb3\x02\n\x08Position\x12\x0e\n\x06isLong\x18\x01 \x01(\x08\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x65ntry_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18\x63umulative_funding_entry\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"8\n\x14MarketOrderIndicator\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05isBuy\x18\x02 \x01(\x08\"\x98\x02\n\x08TradeLog\x12@\n\x08quantity\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x15\n\rsubaccount_id\x18\x03 \x01(\x0c\x12;\n\x03\x66\x65\x65\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\x12#\n\x15\x66\x65\x65_recipient_address\x18\x06 \x01(\x0c\x42\x04\xc8\xde\x1f\x01\"\xff\x01\n\rPositionDelta\x12\x0f\n\x07is_long\x18\x01 \x01(\x08\x12J\n\x12\x65xecution_quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x65xecution_margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12G\n\x0f\x65xecution_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa4\x02\n\x12\x44\x65rivativeTradeLog\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x41\n\x0eposition_delta\x18\x02 \x01(\x0b\x32).injective.exchange.v1beta1.PositionDelta\x12>\n\x06payout\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12;\n\x03\x66\x65\x65\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x12\n\norder_hash\x18\x05 \x01(\x0c\x12#\n\x15\x66\x65\x65_recipient_address\x18\x06 \x01(\x0c\x42\x04\xc8\xde\x1f\x01\"c\n\x12SubaccountPosition\x12\x36\n\x08position\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.Position\x12\x15\n\rsubaccount_id\x18\x02 \x01(\x0c\"`\n\x11SubaccountDeposit\x12\x15\n\rsubaccount_id\x18\x01 \x01(\x0c\x12\x34\n\x07\x64\x65posit\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit\"_\n\rDepositUpdate\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12?\n\x08\x64\x65posits\x18\x02 \x03(\x0b\x32-.injective.exchange.v1beta1.SubaccountDeposit\"\xb4\x01\n\x10PointsMultiplier\x12O\n\x17maker_points_multiplier\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17taker_points_multiplier\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x98\x02\n\x1eTradingRewardCampaignBoostInfo\x12\x1f\n\x17\x62oosted_spot_market_ids\x18\x01 \x03(\t\x12S\n\x17spot_market_multipliers\x18\x02 \x03(\x0b\x32,.injective.exchange.v1beta1.PointsMultiplierB\x04\xc8\xde\x1f\x00\x12%\n\x1d\x62oosted_derivative_market_ids\x18\x03 \x03(\t\x12Y\n\x1d\x64\x65rivative_market_multipliers\x18\x04 \x03(\x0b\x32,.injective.exchange.v1beta1.PointsMultiplierB\x04\xc8\xde\x1f\x00\"\x98\x01\n\x12\x43\x61mpaignRewardPool\x12\x17\n\x0fstart_timestamp\x18\x01 \x01(\x03\x12i\n\x14max_campaign_rewards\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"\xd4\x01\n\x19TradingRewardCampaignInfo\x12!\n\x19\x63\x61mpaign_duration_seconds\x18\x01 \x01(\x03\x12\x14\n\x0cquote_denoms\x18\x02 \x03(\t\x12]\n\x19trading_reward_boost_info\x18\x03 \x01(\x0b\x32:.injective.exchange.v1beta1.TradingRewardCampaignBoostInfo\x12\x1f\n\x17\x64isqualified_market_ids\x18\x04 \x03(\t\"\xb6\x02\n\x13\x46\x65\x65\x44iscountTierInfo\x12K\n\x13maker_discount_rate\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13taker_discount_rate\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x45\n\rstaked_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12>\n\x06volume\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xc0\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12\x14\n\x0c\x62ucket_count\x18\x01 \x01(\x04\x12\x17\n\x0f\x62ucket_duration\x18\x02 \x01(\x03\x12\x14\n\x0cquote_denoms\x18\x03 \x03(\t\x12\x43\n\ntier_infos\x18\x04 \x03(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfo\x12\x1f\n\x17\x64isqualified_market_ids\x18\x05 \x03(\t\"9\n\x12\x46\x65\x65\x44iscountTierTTL\x12\x0c\n\x04tier\x18\x01 \x01(\x04\x12\x15\n\rttl_timestamp\x18\x02 \x01(\x03\"\x9a\x01\n\x0cVolumeRecord\x12\x44\n\x0cmaker_volume\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0ctaker_volume\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x7f\n\x0e\x41\x63\x63ountRewards\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12\\\n\x07rewards\x18\x02 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\"h\n\x0cTradeRecords\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x45\n\x14latest_trade_records\x18\x02 \x03(\x0b\x32\'.injective.exchange.v1beta1.TradeRecord\"\'\n\rSubaccountIDs\x12\x16\n\x0esubaccount_ids\x18\x01 \x03(\x0c\"\xa1\x01\n\x0bTradeRecord\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"}\n\x05Level\x12\x39\n\x01p\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x39\n\x01q\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"z\n\x1f\x41ggregateSubaccountVolumeRecord\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12@\n\x0emarket_volumes\x18\x02 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"q\n\x1c\x41ggregateAccountVolumeRecord\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\x12@\n\x0emarket_volumes\x18\x02 \x03(\x0b\x32(.injective.exchange.v1beta1.MarketVolume\"a\n\x0cMarketVolume\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12>\n\x06volume\x18\x02 \x01(\x0b\x32(.injective.exchange.v1beta1.VolumeRecordB\x04\xc8\xde\x1f\x00\"0\n\rDenomDecimals\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x02 \x01(\x04*t\n\x1c\x41tomicMarketOrderAccessLevel\x12\n\n\x06Nobody\x10\x00\x12\"\n\x1e\x42\x65ginBlockerSmartContractsOnly\x10\x01\x12\x16\n\x12SmartContractsOnly\x10\x02\x12\x0c\n\x08\x45veryone\x10\x03*T\n\x0cMarketStatus\x12\x0f\n\x0bUnspecified\x10\x00\x12\n\n\x06\x41\x63tive\x10\x01\x12\n\n\x06Paused\x10\x02\x12\x0e\n\nDemolished\x10\x03\x12\x0b\n\x07\x45xpired\x10\x04*\xbb\x02\n\tOrderType\x12 \n\x0bUNSPECIFIED\x10\x00\x1a\x0f\x8a\x9d \x0bUNSPECIFIED\x12\x10\n\x03\x42UY\x10\x01\x1a\x07\x8a\x9d \x03\x42UY\x12\x12\n\x04SELL\x10\x02\x1a\x08\x8a\x9d \x04SELL\x12\x1a\n\x08STOP_BUY\x10\x03\x1a\x0c\x8a\x9d \x08STOP_BUY\x12\x1c\n\tSTOP_SELL\x10\x04\x1a\r\x8a\x9d \tSTOP_SELL\x12\x1a\n\x08TAKE_BUY\x10\x05\x1a\x0c\x8a\x9d \x08TAKE_BUY\x12\x1c\n\tTAKE_SELL\x10\x06\x1a\r\x8a\x9d \tTAKE_SELL\x12\x16\n\x06\x42UY_PO\x10\x07\x1a\n\x8a\x9d \x06\x42UY_PO\x12\x18\n\x07SELL_PO\x10\x08\x1a\x0b\x8a\x9d \x07SELL_PO\x12\x1e\n\nBUY_ATOMIC\x10\t\x1a\x0e\x8a\x9d \nBUY_ATOMIC\x12 \n\x0bSELL_ATOMIC\x10\n\x1a\x0f\x8a\x9d \x0bSELL_ATOMIC*\xaf\x01\n\rExecutionType\x12\x1c\n\x18UnspecifiedExecutionType\x10\x00\x12\n\n\x06Market\x10\x01\x12\r\n\tLimitFill\x10\x02\x12\x1a\n\x16LimitMatchRestingOrder\x10\x03\x12\x16\n\x12LimitMatchNewOrder\x10\x04\x12\x15\n\x11MarketLiquidation\x10\x05\x12\x1a\n\x16\x45xpiryMarketSettlement\x10\x06*\x89\x02\n\tOrderMask\x12\x16\n\x06UNUSED\x10\x00\x1a\n\x8a\x9d \x06UNUSED\x12\x10\n\x03\x41NY\x10\x01\x1a\x07\x8a\x9d \x03\x41NY\x12\x18\n\x07REGULAR\x10\x02\x1a\x0b\x8a\x9d \x07REGULAR\x12 \n\x0b\x43ONDITIONAL\x10\x04\x1a\x0f\x8a\x9d \x0b\x43ONDITIONAL\x12.\n\x17\x44IRECTION_BUY_OR_HIGHER\x10\x08\x1a\x11\x8a\x9d \rBUY_OR_HIGHER\x12.\n\x17\x44IRECTION_SELL_OR_LOWER\x10\x10\x1a\x11\x8a\x9d \rSELL_OR_LOWER\x12\x1b\n\x0bTYPE_MARKET\x10 \x1a\n\x8a\x9d \x06MARKET\x12\x19\n\nTYPE_LIMIT\x10@\x1a\t\x8a\x9d \x05LIMITBPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.exchange.v1beta1.exchange_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types'
  _ORDERTYPE.values_by_name["UNSPECIFIED"]._options = None
  _ORDERTYPE.values_by_name["UNSPECIFIED"]._serialized_options = b'\212\235 \013UNSPECIFIED'
  _ORDERTYPE.values_by_name["BUY"]._options = None
  _ORDERTYPE.values_by_name["BUY"]._serialized_options = b'\212\235 \003BUY'
  _ORDERTYPE.values_by_name["SELL"]._options = None
  _ORDERTYPE.values_by_name["SELL"]._serialized_options = b'\212\235 \004SELL'
  _ORDERTYPE.values_by_name["STOP_BUY"]._options = None
  _ORDERTYPE.values_by_name["STOP_BUY"]._serialized_options = b'\212\235 \010STOP_BUY'
  _ORDERTYPE.values_by_name["STOP_SELL"]._options = None
  _ORDERTYPE.values_by_name["STOP_SELL"]._serialized_options = b'\212\235 \tSTOP_SELL'
  _ORDERTYPE.values_by_name["TAKE_BUY"]._options = None
  _ORDERTYPE.values_by_name["TAKE_BUY"]._serialized_options = b'\212\235 \010TAKE_BUY'
  _ORDERTYPE.values_by_name["TAKE_SELL"]._options = None
  _ORDERTYPE.values_by_name["TAKE_SELL"]._serialized_options = b'\212\235 \tTAKE_SELL'
  _ORDERTYPE.values_by_name["BUY_PO"]._options = None
  _ORDERTYPE.values_by_name["BUY_PO"]._serialized_options = b'\212\235 \006BUY_PO'
  _ORDERTYPE.values_by_name["SELL_PO"]._options = None
  _ORDERTYPE.values_by_name["SELL_PO"]._serialized_options = b'\212\235 \007SELL_PO'
  _ORDERTYPE.values_by_name["BUY_ATOMIC"]._options = None
  _ORDERTYPE.values_by_name["BUY_ATOMIC"]._serialized_options = b'\212\235 \nBUY_ATOMIC'
  _ORDERTYPE.values_by_name["SELL_ATOMIC"]._options = None
  _ORDERTYPE.values_by_name["SELL_ATOMIC"]._serialized_options = b'\212\235 \013SELL_ATOMIC'
  _ORDERMASK.values_by_name["UNUSED"]._options = None
  _ORDERMASK.values_by_name["UNUSED"]._serialized_options = b'\212\235 \006UNUSED'
  _ORDERMASK.values_by_name["ANY"]._options = None
  _ORDERMASK.values_by_name["ANY"]._serialized_options = b'\212\235 \003ANY'
  _ORDERMASK.values_by_name["REGULAR"]._options = None
  _ORDERMASK.values_by_name["REGULAR"]._serialized_options = b'\212\235 \007REGULAR'
  _ORDERMASK.values_by_name["CONDITIONAL"]._options = None
  _ORDERMASK.values_by_name["CONDITIONAL"]._serialized_options = b'\212\235 \013CONDITIONAL'
  _ORDERMASK.values_by_name["DIRECTION_BUY_OR_HIGHER"]._options = None
  _ORDERMASK.values_by_name["DIRECTION_BUY_OR_HIGHER"]._serialized_options = b'\212\235 \rBUY_OR_HIGHER'
  _ORDERMASK.values_by_name["DIRECTION_SELL_OR_LOWER"]._options = None
  _ORDERMASK.values_by_name["DIRECTION_SELL_OR_LOWER"]._serialized_options = b'\212\235 \rSELL_OR_LOWER'
  _ORDERMASK.values_by_name["TYPE_MARKET"]._options = None
  _ORDERMASK.values_by_name["TYPE_MARKET"]._serialized_options = b'\212\235 \006MARKET'
  _ORDERMASK.values_by_name["TYPE_LIMIT"]._options = None
  _ORDERMASK.values_by_name["TYPE_LIMIT"]._serialized_options = b'\212\235 \005LIMIT'
  _PARAMS.fields_by_name['spot_market_instant_listing_fee']._options = None
  _PARAMS.fields_by_name['spot_market_instant_listing_fee']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['derivative_market_instant_listing_fee']._options = None
  _PARAMS.fields_by_name['derivative_market_instant_listing_fee']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['default_spot_maker_fee_rate']._options = None
  _PARAMS.fields_by_name['default_spot_maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_spot_taker_fee_rate']._options = None
  _PARAMS.fields_by_name['default_spot_taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_derivative_maker_fee_rate']._options = None
  _PARAMS.fields_by_name['default_derivative_maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_derivative_taker_fee_rate']._options = None
  _PARAMS.fields_by_name['default_derivative_taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_initial_margin_ratio']._options = None
  _PARAMS.fields_by_name['default_initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_maintenance_margin_ratio']._options = None
  _PARAMS.fields_by_name['default_maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['relayer_fee_share_rate']._options = None
  _PARAMS.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_hourly_funding_rate_cap']._options = None
  _PARAMS.fields_by_name['default_hourly_funding_rate_cap']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['default_hourly_interest_rate']._options = None
  _PARAMS.fields_by_name['default_hourly_interest_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['inj_reward_staked_requirement_threshold']._options = None
  _PARAMS.fields_by_name['inj_reward_staked_requirement_threshold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _PARAMS.fields_by_name['liquidator_reward_share_rate']._options = None
  _PARAMS.fields_by_name['liquidator_reward_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['binary_options_market_instant_listing_fee']._options = None
  _PARAMS.fields_by_name['binary_options_market_instant_listing_fee']._serialized_options = b'\310\336\037\000'
  _PARAMS.fields_by_name['spot_atomic_market_order_fee_multiplier']._options = None
  _PARAMS.fields_by_name['spot_atomic_market_order_fee_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['derivative_atomic_market_order_fee_multiplier']._options = None
  _PARAMS.fields_by_name['derivative_atomic_market_order_fee_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['binary_options_atomic_market_order_fee_multiplier']._options = None
  _PARAMS.fields_by_name['binary_options_atomic_market_order_fee_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['minimal_protocol_fee_rate']._options = None
  _PARAMS.fields_by_name['minimal_protocol_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001'
  _MARKETFEEMULTIPLIER.fields_by_name['fee_multiplier']._options = None
  _MARKETFEEMULTIPLIER.fields_by_name['fee_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKETFEEMULTIPLIER._options = None
  _MARKETFEEMULTIPLIER._serialized_options = b'\210\240\037\000'
  _DERIVATIVEMARKET.fields_by_name['initial_margin_ratio']._options = None
  _DERIVATIVEMARKET.fields_by_name['initial_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['maintenance_margin_ratio']._options = None
  _DERIVATIVEMARKET.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['maker_fee_rate']._options = None
  _DERIVATIVEMARKET.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['taker_fee_rate']._options = None
  _DERIVATIVEMARKET.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['relayer_fee_share_rate']._options = None
  _DERIVATIVEMARKET.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['min_price_tick_size']._options = None
  _DERIVATIVEMARKET.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET.fields_by_name['min_quantity_tick_size']._options = None
  _DERIVATIVEMARKET.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKET._options = None
  _DERIVATIVEMARKET._serialized_options = b'\210\240\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['maker_fee_rate']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['taker_fee_rate']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['relayer_fee_share_rate']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['min_price_tick_size']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['min_quantity_tick_size']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _BINARYOPTIONSMARKET.fields_by_name['settlement_price']._options = None
  _BINARYOPTIONSMARKET.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _BINARYOPTIONSMARKET._options = None
  _BINARYOPTIONSMARKET._serialized_options = b'\210\240\037\000'
  _EXPIRYFUTURESMARKETINFO.fields_by_name['expiration_twap_start_price_cumulative']._options = None
  _EXPIRYFUTURESMARKETINFO.fields_by_name['expiration_twap_start_price_cumulative']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXPIRYFUTURESMARKETINFO.fields_by_name['settlement_price']._options = None
  _EXPIRYFUTURESMARKETINFO.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETINFO.fields_by_name['hourly_funding_rate_cap']._options = None
  _PERPETUALMARKETINFO.fields_by_name['hourly_funding_rate_cap']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETINFO.fields_by_name['hourly_interest_rate']._options = None
  _PERPETUALMARKETINFO.fields_by_name['hourly_interest_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETFUNDING.fields_by_name['cumulative_funding']._options = None
  _PERPETUALMARKETFUNDING.fields_by_name['cumulative_funding']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PERPETUALMARKETFUNDING.fields_by_name['cumulative_price']._options = None
  _PERPETUALMARKETFUNDING.fields_by_name['cumulative_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETSETTLEMENTINFO.fields_by_name['settlement_price']._options = None
  _DERIVATIVEMARKETSETTLEMENTINFO.fields_by_name['settlement_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKET.fields_by_name['maker_fee_rate']._options = None
  _SPOTMARKET.fields_by_name['maker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKET.fields_by_name['taker_fee_rate']._options = None
  _SPOTMARKET.fields_by_name['taker_fee_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKET.fields_by_name['relayer_fee_share_rate']._options = None
  _SPOTMARKET.fields_by_name['relayer_fee_share_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKET.fields_by_name['min_price_tick_size']._options = None
  _SPOTMARKET.fields_by_name['min_price_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKET.fields_by_name['min_quantity_tick_size']._options = None
  _SPOTMARKET.fields_by_name['min_quantity_tick_size']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DEPOSIT.fields_by_name['available_balance']._options = None
  _DEPOSIT.fields_by_name['available_balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DEPOSIT.fields_by_name['total_balance']._options = None
  _DEPOSIT.fields_by_name['total_balance']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _ORDERINFO.fields_by_name['price']._options = None
  _ORDERINFO.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _ORDERINFO.fields_by_name['quantity']._options = None
  _ORDERINFO.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTORDER.fields_by_name['order_info']._options = None
  _SPOTORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _SPOTORDER.fields_by_name['trigger_price']._options = None
  _SPOTORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTLIMITORDER.fields_by_name['order_info']._options = None
  _SPOTLIMITORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _SPOTLIMITORDER.fields_by_name['fillable']._options = None
  _SPOTLIMITORDER.fields_by_name['fillable']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTLIMITORDER.fields_by_name['trigger_price']._options = None
  _SPOTLIMITORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SPOTMARKETORDER.fields_by_name['order_info']._options = None
  _SPOTMARKETORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _SPOTMARKETORDER.fields_by_name['balance_hold']._options = None
  _SPOTMARKETORDER.fields_by_name['balance_hold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SPOTMARKETORDER.fields_by_name['trigger_price']._options = None
  _SPOTMARKETORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEORDER.fields_by_name['order_info']._options = None
  _DERIVATIVEORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _DERIVATIVEORDER.fields_by_name['margin']._options = None
  _DERIVATIVEORDER.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEORDER.fields_by_name['trigger_price']._options = None
  _DERIVATIVEORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_reduce_only_quantity']._options = None
  _SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_reduce_only_quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_vanilla_quantity']._options = None
  _SUBACCOUNTORDERBOOKMETADATA.fields_by_name['aggregate_vanilla_quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SUBACCOUNTORDER.fields_by_name['price']._options = None
  _SUBACCOUNTORDER.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _SUBACCOUNTORDER.fields_by_name['quantity']._options = None
  _SUBACCOUNTORDER.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVELIMITORDER.fields_by_name['order_info']._options = None
  _DERIVATIVELIMITORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _DERIVATIVELIMITORDER.fields_by_name['margin']._options = None
  _DERIVATIVELIMITORDER.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVELIMITORDER.fields_by_name['fillable']._options = None
  _DERIVATIVELIMITORDER.fields_by_name['fillable']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVELIMITORDER.fields_by_name['trigger_price']._options = None
  _DERIVATIVELIMITORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _DERIVATIVEMARKETORDER.fields_by_name['order_info']._options = None
  _DERIVATIVEMARKETORDER.fields_by_name['order_info']._serialized_options = b'\310\336\037\000'
  _DERIVATIVEMARKETORDER.fields_by_name['margin']._options = None
  _DERIVATIVEMARKETORDER.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDER.fields_by_name['margin_hold']._options = None
  _DERIVATIVEMARKETORDER.fields_by_name['margin_hold']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVEMARKETORDER.fields_by_name['trigger_price']._options = None
  _DERIVATIVEMARKETORDER.fields_by_name['trigger_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001'
  _POSITION.fields_by_name['quantity']._options = None
  _POSITION.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['entry_price']._options = None
  _POSITION.fields_by_name['entry_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['margin']._options = None
  _POSITION.fields_by_name['margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITION.fields_by_name['cumulative_funding_entry']._options = None
  _POSITION.fields_by_name['cumulative_funding_entry']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADELOG.fields_by_name['quantity']._options = None
  _TRADELOG.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADELOG.fields_by_name['price']._options = None
  _TRADELOG.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADELOG.fields_by_name['fee']._options = None
  _TRADELOG.fields_by_name['fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADELOG.fields_by_name['fee_recipient_address']._options = None
  _TRADELOG.fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _POSITIONDELTA.fields_by_name['execution_quantity']._options = None
  _POSITIONDELTA.fields_by_name['execution_quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONDELTA.fields_by_name['execution_margin']._options = None
  _POSITIONDELTA.fields_by_name['execution_margin']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POSITIONDELTA.fields_by_name['execution_price']._options = None
  _POSITIONDELTA.fields_by_name['execution_price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVETRADELOG.fields_by_name['payout']._options = None
  _DERIVATIVETRADELOG.fields_by_name['payout']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVETRADELOG.fields_by_name['fee']._options = None
  _DERIVATIVETRADELOG.fields_by_name['fee']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _DERIVATIVETRADELOG.fields_by_name['fee_recipient_address']._options = None
  _DERIVATIVETRADELOG.fields_by_name['fee_recipient_address']._serialized_options = b'\310\336\037\001'
  _POINTSMULTIPLIER.fields_by_name['maker_points_multiplier']._options = None
  _POINTSMULTIPLIER.fields_by_name['maker_points_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _POINTSMULTIPLIER.fields_by_name['taker_points_multiplier']._options = None
  _POINTSMULTIPLIER.fields_by_name['taker_points_multiplier']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['spot_market_multipliers']._options = None
  _TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['spot_market_multipliers']._serialized_options = b'\310\336\037\000'
  _TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['derivative_market_multipliers']._options = None
  _TRADINGREWARDCAMPAIGNBOOSTINFO.fields_by_name['derivative_market_multipliers']._serialized_options = b'\310\336\037\000'
  _CAMPAIGNREWARDPOOL.fields_by_name['max_campaign_rewards']._options = None
  _CAMPAIGNREWARDPOOL.fields_by_name['max_campaign_rewards']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _FEEDISCOUNTTIERINFO.fields_by_name['maker_discount_rate']._options = None
  _FEEDISCOUNTTIERINFO.fields_by_name['maker_discount_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _FEEDISCOUNTTIERINFO.fields_by_name['taker_discount_rate']._options = None
  _FEEDISCOUNTTIERINFO.fields_by_name['taker_discount_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _FEEDISCOUNTTIERINFO.fields_by_name['staked_amount']._options = None
  _FEEDISCOUNTTIERINFO.fields_by_name['staked_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _FEEDISCOUNTTIERINFO.fields_by_name['volume']._options = None
  _FEEDISCOUNTTIERINFO.fields_by_name['volume']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _VOLUMERECORD.fields_by_name['maker_volume']._options = None
  _VOLUMERECORD.fields_by_name['maker_volume']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _VOLUMERECORD.fields_by_name['taker_volume']._options = None
  _VOLUMERECORD.fields_by_name['taker_volume']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _ACCOUNTREWARDS.fields_by_name['rewards']._options = None
  _ACCOUNTREWARDS.fields_by_name['rewards']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _TRADERECORD.fields_by_name['price']._options = None
  _TRADERECORD.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _TRADERECORD.fields_by_name['quantity']._options = None
  _TRADERECORD.fields_by_name['quantity']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _LEVEL.fields_by_name['p']._options = None
  _LEVEL.fields_by_name['p']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _LEVEL.fields_by_name['q']._options = None
  _LEVEL.fields_by_name['q']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MARKETVOLUME.fields_by_name['volume']._options = None
  _MARKETVOLUME.fields_by_name['volume']._serialized_options = b'\310\336\037\000'
  _ATOMICMARKETORDERACCESSLEVEL._serialized_start=12194
  _ATOMICMARKETORDERACCESSLEVEL._serialized_end=12310
  _MARKETSTATUS._serialized_start=12312
  _MARKETSTATUS._serialized_end=12396
  _ORDERTYPE._serialized_start=12399
  _ORDERTYPE._serialized_end=12714
  _EXECUTIONTYPE._serialized_start=12717
  _EXECUTIONTYPE._serialized_end=12892
  _ORDERMASK._serialized_start=12895
  _ORDERMASK._serialized_end=13160
  _PARAMS._serialized_start=167
  _PARAMS._serialized_end=2071
  _MARKETFEEMULTIPLIER._serialized_start=2073
  _MARKETFEEMULTIPLIER._serialized_end=2191
  _DERIVATIVEMARKET._serialized_start=2194
  _DERIVATIVEMARKET._serialized_end=3025
  _BINARYOPTIONSMARKET._serialized_start=3028
  _BINARYOPTIONSMARKET._serialized_end=3835
  _EXPIRYFUTURESMARKETINFO._serialized_start=3838
  _EXPIRYFUTURESMARKETINFO._serialized_end=4112
  _PERPETUALMARKETINFO._serialized_start=4115
  _PERPETUALMARKETINFO._serialized_end=4372
  _PERPETUALMARKETFUNDING._serialized_start=4375
  _PERPETUALMARKETFUNDING._serialized_end=4573
  _DERIVATIVEMARKETSETTLEMENTINFO._serialized_start=4575
  _DERIVATIVEMARKETSETTLEMENTINFO._serialized_end=4700
  _NEXTFUNDINGTIMESTAMP._serialized_start=4702
  _NEXTFUNDINGTIMESTAMP._serialized_end=4748
  _SPOTMARKET._serialized_start=4751
  _SPOTMARKET._serialized_end=5278
  _DEPOSIT._serialized_start=5281
  _DEPOSIT._serialized_end=5436
  _SUBACCOUNTTRADENONCE._serialized_start=5438
  _SUBACCOUNTTRADENONCE._serialized_end=5475
  _ORDERINFO._serialized_start=5478
  _ORDERINFO._serialized_end=5664
  _SPOTORDER._serialized_start=5667
  _SPOTORDER._serialized_end=5892
  _SPOTLIMITORDER._serialized_start=5895
  _SPOTLIMITORDER._serialized_end=6192
  _SPOTMARKETORDER._serialized_start=6195
  _SPOTMARKETORDER._serialized_end=6497
  _DERIVATIVEORDER._serialized_start=6500
  _DERIVATIVEORDER._serialized_end=6795
  _SUBACCOUNTORDERBOOKMETADATA._serialized_start=6798
  _SUBACCOUNTORDERBOOKMETADATA._serialized_end=7159
  _SUBACCOUNTORDER._serialized_start=7162
  _SUBACCOUNTORDER._serialized_end=7330
  _SUBACCOUNTORDERDATA._serialized_start=7332
  _SUBACCOUNTORDERDATA._serialized_end=7433
  _DERIVATIVELIMITORDER._serialized_start=7436
  _DERIVATIVELIMITORDER._serialized_end=7803
  _DERIVATIVEMARKETORDER._serialized_start=7806
  _DERIVATIVEMARKETORDER._serialized_end=8177
  _POSITION._serialized_start=8180
  _POSITION._serialized_end=8487
  _MARKETORDERINDICATOR._serialized_start=8489
  _MARKETORDERINDICATOR._serialized_end=8545
  _TRADELOG._serialized_start=8548
  _TRADELOG._serialized_end=8828
  _POSITIONDELTA._serialized_start=8831
  _POSITIONDELTA._serialized_end=9086
  _DERIVATIVETRADELOG._serialized_start=9089
  _DERIVATIVETRADELOG._serialized_end=9381
  _SUBACCOUNTPOSITION._serialized_start=9383
  _SUBACCOUNTPOSITION._serialized_end=9482
  _SUBACCOUNTDEPOSIT._serialized_start=9484
  _SUBACCOUNTDEPOSIT._serialized_end=9580
  _DEPOSITUPDATE._serialized_start=9582
  _DEPOSITUPDATE._serialized_end=9677
  _POINTSMULTIPLIER._serialized_start=9680
  _POINTSMULTIPLIER._serialized_end=9860
  _TRADINGREWARDCAMPAIGNBOOSTINFO._serialized_start=9863
  _TRADINGREWARDCAMPAIGNBOOSTINFO._serialized_end=10143
  _CAMPAIGNREWARDPOOL._serialized_start=10146
  _CAMPAIGNREWARDPOOL._serialized_end=10298
  _TRADINGREWARDCAMPAIGNINFO._serialized_start=10301
  _TRADINGREWARDCAMPAIGNINFO._serialized_end=10513
  _FEEDISCOUNTTIERINFO._serialized_start=10516
  _FEEDISCOUNTTIERINFO._serialized_end=10826
  _FEEDISCOUNTSCHEDULE._serialized_start=10829
  _FEEDISCOUNTSCHEDULE._serialized_end=11021
  _FEEDISCOUNTTIERTTL._serialized_start=11023
  _FEEDISCOUNTTIERTTL._serialized_end=11080
  _VOLUMERECORD._serialized_start=11083
  _VOLUMERECORD._serialized_end=11237
  _ACCOUNTREWARDS._serialized_start=11239
  _ACCOUNTREWARDS._serialized_end=11366
  _TRADERECORDS._serialized_start=11368
  _TRADERECORDS._serialized_end=11472
  _SUBACCOUNTIDS._serialized_start=11474
  _SUBACCOUNTIDS._serialized_end=11513
  _TRADERECORD._serialized_start=11516
  _TRADERECORD._serialized_end=11677
  _LEVEL._serialized_start=11679
  _LEVEL._serialized_end=11804
  _AGGREGATESUBACCOUNTVOLUMERECORD._serialized_start=11806
  _AGGREGATESUBACCOUNTVOLUMERECORD._serialized_end=11928
  _AGGREGATEACCOUNTVOLUMERECORD._serialized_start=11930
  _AGGREGATEACCOUNTVOLUMERECORD._serialized_end=12043
  _MARKETVOLUME._serialized_start=12045
  _MARKETVOLUME._serialized_end=12142
  _DENOMDECIMALS._serialized_start=12144
  _DENOMDECIMALS._serialized_end=12192
# @@protoc_insertion_point(module_scope)
