# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!injective/oracle/v1beta1/tx.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x95\x01\n\x16MsgRelayProviderPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0f\n\x07symbols\x18\x03 \x03(\t\x12>\n\x06prices\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayProviderPricesResponse\"\x8e\x01\n\x16MsgRelayPriceFeedPrice\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0c\n\x04\x62\x61se\x18\x02 \x03(\t\x12\r\n\x05quote\x18\x03 \x03(\t\x12=\n\x05price\x18\x04 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRelayPriceFeedPriceResponse\"o\n\x11MsgRelayBandRates\x12\x0f\n\x07relayer\x18\x01 \x01(\t\x12\x0f\n\x07symbols\x18\x02 \x03(\t\x12\r\n\x05rates\x18\x03 \x03(\x04\x12\x15\n\rresolve_times\x18\x04 \x03(\x04\x12\x12\n\nrequestIDs\x18\x05 \x03(\x04\"\x1b\n\x19MsgRelayBandRatesResponse\"Z\n\x18MsgRelayCoinbaseMessages\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08messages\x18\x02 \x03(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\"\n MsgRelayCoinbaseMessagesResponse\"F\n\x16MsgRequestBandIBCRates\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x12\n\nrequest_id\x18\x02 \x01(\x04:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgRequestBandIBCRatesResponse\"v\n\x12MsgRelayPythPrices\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x46\n\x12price_attestations\x18\x02 \x03(\x0b\x32*.injective.oracle.v1beta1.PriceAttestation:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1c\n\x1aMsgRelayPythPricesResponse2\x86\x06\n\x03Msg\x12\x81\x01\n\x13RelayProviderPrices\x12\x30.injective.oracle.v1beta1.MsgRelayProviderPrices\x1a\x38.injective.oracle.v1beta1.MsgRelayProviderPricesResponse\x12\x81\x01\n\x13RelayPriceFeedPrice\x12\x30.injective.oracle.v1beta1.MsgRelayPriceFeedPrice\x1a\x38.injective.oracle.v1beta1.MsgRelayPriceFeedPriceResponse\x12r\n\x0eRelayBandRates\x12+.injective.oracle.v1beta1.MsgRelayBandRates\x1a\x33.injective.oracle.v1beta1.MsgRelayBandRatesResponse\x12\x81\x01\n\x13RequestBandIBCRates\x12\x30.injective.oracle.v1beta1.MsgRequestBandIBCRates\x1a\x38.injective.oracle.v1beta1.MsgRequestBandIBCRatesResponse\x12\x87\x01\n\x15RelayCoinbaseMessages\x12\x32.injective.oracle.v1beta1.MsgRelayCoinbaseMessages\x1a:.injective.oracle.v1beta1.MsgRelayCoinbaseMessagesResponse\x12u\n\x0fRelayPythPrices\x12,.injective.oracle.v1beta1.MsgRelayPythPrices\x1a\x34.injective.oracle.v1beta1.MsgRelayPythPricesResponseBNZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types'
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._options = None
  _MSGRELAYPROVIDERPRICES.fields_by_name['prices']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGRELAYPROVIDERPRICES._options = None
  _MSGRELAYPROVIDERPRICES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._options = None
  _MSGRELAYPRICEFEEDPRICE.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _MSGRELAYPRICEFEEDPRICE._options = None
  _MSGRELAYPRICEFEEDPRICE._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYCOINBASEMESSAGES._options = None
  _MSGRELAYCOINBASEMESSAGES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGREQUESTBANDIBCRATES._options = None
  _MSGREQUESTBANDIBCRATES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPYTHPRICES._options = None
  _MSGRELAYPYTHPRICES._serialized_options = b'\350\240\037\000\210\240\037\000'
  _MSGRELAYPROVIDERPRICES._serialized_start=125
  _MSGRELAYPROVIDERPRICES._serialized_end=274
  _MSGRELAYPROVIDERPRICESRESPONSE._serialized_start=276
  _MSGRELAYPROVIDERPRICESRESPONSE._serialized_end=308
  _MSGRELAYPRICEFEEDPRICE._serialized_start=311
  _MSGRELAYPRICEFEEDPRICE._serialized_end=453
  _MSGRELAYPRICEFEEDPRICERESPONSE._serialized_start=455
  _MSGRELAYPRICEFEEDPRICERESPONSE._serialized_end=487
  _MSGRELAYBANDRATES._serialized_start=489
  _MSGRELAYBANDRATES._serialized_end=600
  _MSGRELAYBANDRATESRESPONSE._serialized_start=602
  _MSGRELAYBANDRATESRESPONSE._serialized_end=629
  _MSGRELAYCOINBASEMESSAGES._serialized_start=631
  _MSGRELAYCOINBASEMESSAGES._serialized_end=721
  _MSGRELAYCOINBASEMESSAGESRESPONSE._serialized_start=723
  _MSGRELAYCOINBASEMESSAGESRESPONSE._serialized_end=757
  _MSGREQUESTBANDIBCRATES._serialized_start=759
  _MSGREQUESTBANDIBCRATES._serialized_end=829
  _MSGREQUESTBANDIBCRATESRESPONSE._serialized_start=831
  _MSGREQUESTBANDIBCRATESRESPONSE._serialized_end=863
  _MSGRELAYPYTHPRICES._serialized_start=865
  _MSGRELAYPYTHPRICES._serialized_end=983
  _MSGRELAYPYTHPRICESRESPONSE._serialized_start=985
  _MSGRELAYPYTHPRICESRESPONSE._serialized_end=1013
  _MSG._serialized_start=1016
  _MSG._serialized_end=1790
# @@protoc_insertion_point(module_scope)
