# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_meta_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!exchange/injective_meta_rpc.proto\x12\x12injective_meta_rpc\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x10\n\x0eVersionRequest\"\x8f\x01\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12=\n\x05\x62uild\x18\x02 \x03(\x0b\x32..injective_meta_rpc.VersionResponse.BuildEntry\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\" \n\x0bInfoRequest\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\"\xc1\x01\n\x0cInfoResponse\x12\x11\n\ttimestamp\x18\x01 \x01(\x12\x12\x13\n\x0bserver_time\x18\x02 \x01(\x12\x12\x0f\n\x07version\x18\x03 \x01(\t\x12:\n\x05\x62uild\x18\x04 \x03(\x0b\x32+.injective_meta_rpc.InfoResponse.BuildEntry\x12\x0e\n\x06region\x18\x05 \x01(\t\x1a,\n\nBuildEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x18\n\x16StreamKeepaliveRequest\"Q\n\x17StreamKeepaliveResponse\x12\r\n\x05\x65vent\x18\x01 \x01(\t\x12\x14\n\x0cnew_endpoint\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\x12\"&\n\x14TokenMetadataRequest\x12\x0e\n\x06\x64\x65noms\x18\x01 \x03(\t\"Q\n\x15TokenMetadataResponse\x12\x38\n\x06tokens\x18\x01 \x03(\x0b\x32(.injective_meta_rpc.TokenMetadataElement\"\x93\x01\n\x14TokenMetadataElement\x12\x18\n\x10\x65thereum_address\x18\x01 \x01(\t\x12\x14\n\x0c\x63oingecko_id\x18\x02 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0e\n\x06symbol\x18\x05 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x06 \x01(\x11\x12\x0c\n\x04logo\x18\x07 \x01(\t2\xd0\x03\n\x10InjectiveMetaRPC\x12I\n\x04Ping\x12\x1f.injective_meta_rpc.PingRequest\x1a .injective_meta_rpc.PingResponse\x12R\n\x07Version\x12\".injective_meta_rpc.VersionRequest\x1a#.injective_meta_rpc.VersionResponse\x12I\n\x04Info\x12\x1f.injective_meta_rpc.InfoRequest\x1a .injective_meta_rpc.InfoResponse\x12l\n\x0fStreamKeepalive\x12*.injective_meta_rpc.StreamKeepaliveRequest\x1a+.injective_meta_rpc.StreamKeepaliveResponse0\x01\x12\x64\n\rTokenMetadata\x12(.injective_meta_rpc.TokenMetadataRequest\x1a).injective_meta_rpc.TokenMetadataResponseB\x17Z\x15/injective_meta_rpcpbb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_meta_rpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\025/injective_meta_rpcpb'
  _VERSIONRESPONSE_BUILDENTRY._options = None
  _VERSIONRESPONSE_BUILDENTRY._serialized_options = b'8\001'
  _INFORESPONSE_BUILDENTRY._options = None
  _INFORESPONSE_BUILDENTRY._serialized_options = b'8\001'
  _PINGREQUEST._serialized_start=57
  _PINGREQUEST._serialized_end=70
  _PINGRESPONSE._serialized_start=72
  _PINGRESPONSE._serialized_end=86
  _VERSIONREQUEST._serialized_start=88
  _VERSIONREQUEST._serialized_end=104
  _VERSIONRESPONSE._serialized_start=107
  _VERSIONRESPONSE._serialized_end=250
  _VERSIONRESPONSE_BUILDENTRY._serialized_start=206
  _VERSIONRESPONSE_BUILDENTRY._serialized_end=250
  _INFOREQUEST._serialized_start=252
  _INFOREQUEST._serialized_end=284
  _INFORESPONSE._serialized_start=287
  _INFORESPONSE._serialized_end=480
  _INFORESPONSE_BUILDENTRY._serialized_start=206
  _INFORESPONSE_BUILDENTRY._serialized_end=250
  _STREAMKEEPALIVEREQUEST._serialized_start=482
  _STREAMKEEPALIVEREQUEST._serialized_end=506
  _STREAMKEEPALIVERESPONSE._serialized_start=508
  _STREAMKEEPALIVERESPONSE._serialized_end=589
  _TOKENMETADATAREQUEST._serialized_start=591
  _TOKENMETADATAREQUEST._serialized_end=629
  _TOKENMETADATARESPONSE._serialized_start=631
  _TOKENMETADATARESPONSE._serialized_end=712
  _TOKENMETADATAELEMENT._serialized_start=715
  _TOKENMETADATAELEMENT._serialized_end=862
  _INJECTIVEMETARPC._serialized_start=865
  _INJECTIVEMETARPC._serialized_end=1329
# @@protoc_insertion_point(module_scope)
