# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1finjective/peggy/v1/events.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1einjective/peggy/v1/types.proto\"\xac\x01\n\x18\x45ventAttestationObserved\x12\x37\n\x10\x61ttestation_type\x18\x01 \x01(\x0e\x32\x1d.injective.peggy.v1.ClaimType\x12\x17\n\x0f\x62ridge_contract\x18\x02 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x03 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x04 \x01(\x0c\x12\r\n\x05nonce\x18\x05 \x01(\x04\"O\n\x1b\x45ventBridgeWithdrawCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\"\x83\x01\n\x12\x45ventOutgoingBatch\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x13\n\x0b\x62\x61tch_nonce\x18\x03 \x01(\x04\x12\x15\n\rbatch_timeout\x18\x04 \x01(\x04\x12\x14\n\x0c\x62\x61tch_tx_ids\x18\x05 \x03(\x04\"o\n\x1a\x45ventOutgoingBatchCanceled\x12\x17\n\x0f\x62ridge_contract\x18\x01 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x02 \x01(\x04\x12\x10\n\x08\x62\x61tch_id\x18\x03 \x01(\x04\x12\r\n\x05nonce\x18\x04 \x01(\x04\"\xe1\x01\n\x18\x45ventValsetUpdateRequest\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x15\n\rvalset_height\x18\x02 \x01(\x04\x12;\n\x0evalset_members\x18\x03 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x05 \x01(\t\"v\n\x1d\x45ventSetOrchestratorAddresses\x12\x19\n\x11validator_address\x18\x01 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\x12\x1c\n\x14operator_eth_address\x18\x03 \x01(\t\"H\n\x12\x45ventValsetConfirm\x12\x14\n\x0cvalset_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"\xd0\x01\n\x0e\x45ventSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\x12\x0e\n\x06sender\x18\x02 \x01(\t\x12\x10\n\x08receiver\x18\x03 \x01(\t\x12?\n\x06\x61mount\x18\x04 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\x12\x43\n\nbridge_fee\x18\x05 \x01(\tB/\xda\xde\x1f\'github.com/cosmos/cosmos-sdk/types.Coin\xc8\xde\x1f\x00\"F\n\x11\x45ventConfirmBatch\x12\x13\n\x0b\x62\x61tch_nonce\x18\x01 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\x02 \x01(\t\"R\n\x14\x45ventAttestationVote\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x02 \x01(\x0c\x12\r\n\x05voter\x18\x03 \x01(\t\"\x8c\x02\n\x11\x45ventDepositClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x17\n\x0f\x65thereum_sender\x18\x04 \x01(\t\x12\x17\n\x0f\x63osmos_receiver\x18\x05 \x01(\t\x12\x16\n\x0etoken_contract\x18\x06 \x01(\t\x12>\n\x06\x61mount\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\t \x01(\t\"\xa2\x01\n\x12\x45ventWithdrawClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x13\n\x0b\x62\x61tch_nonce\x18\x04 \x01(\x04\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x06 \x01(\t\"\xd8\x01\n\x17\x45ventERC20DeployedClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0c\x63osmos_denom\x18\x04 \x01(\t\x12\x16\n\x0etoken_contract\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0e\n\x06symbol\x18\x07 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x08 \x01(\x04\x12\x1c\n\x14orchestrator_address\x18\t \x01(\t\"\xa9\x02\n\x16\x45ventValsetUpdateClaim\x12\x13\n\x0b\x65vent_nonce\x18\x01 \x01(\x04\x12\x14\n\x0c\x65vent_height\x18\x02 \x01(\x04\x12\x16\n\x0e\x61ttestation_id\x18\x03 \x01(\x0c\x12\x14\n\x0cvalset_nonce\x18\x04 \x01(\x04\x12;\n\x0evalset_members\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.BridgeValidator\x12\x45\n\rreward_amount\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00\x12\x14\n\x0creward_token\x18\x07 \x01(\t\x12\x1c\n\x14orchestrator_address\x18\x08 \x01(\t\".\n\x14\x45ventCancelSendToEth\x12\x16\n\x0eoutgoing_tx_id\x18\x01 \x01(\x04\"_\n\x1f\x45ventSubmitBadSignatureEvidence\x12\x19\n\x11\x62\x61\x64_eth_signature\x18\x01 \x01(\t\x12!\n\x19\x62\x61\x64_eth_signature_subject\x18\x02 \x01(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._options = None
  _EVENTVALSETUPDATEREQUEST.fields_by_name['reward_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTSENDTOETH.fields_by_name['amount']._options = None
  _EVENTSENDTOETH.fields_by_name['amount']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTSENDTOETH.fields_by_name['bridge_fee']._options = None
  _EVENTSENDTOETH.fields_by_name['bridge_fee']._serialized_options = b'\332\336\037\'github.com/cosmos/cosmos-sdk/types.Coin\310\336\037\000'
  _EVENTDEPOSITCLAIM.fields_by_name['amount']._options = None
  _EVENTDEPOSITCLAIM.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._options = None
  _EVENTVALSETUPDATECLAIM.fields_by_name['reward_amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _EVENTATTESTATIONOBSERVED._serialized_start=148
  _EVENTATTESTATIONOBSERVED._serialized_end=320
  _EVENTBRIDGEWITHDRAWCANCELED._serialized_start=322
  _EVENTBRIDGEWITHDRAWCANCELED._serialized_end=401
  _EVENTOUTGOINGBATCH._serialized_start=404
  _EVENTOUTGOINGBATCH._serialized_end=535
  _EVENTOUTGOINGBATCHCANCELED._serialized_start=537
  _EVENTOUTGOINGBATCHCANCELED._serialized_end=648
  _EVENTVALSETUPDATEREQUEST._serialized_start=651
  _EVENTVALSETUPDATEREQUEST._serialized_end=876
  _EVENTSETORCHESTRATORADDRESSES._serialized_start=878
  _EVENTSETORCHESTRATORADDRESSES._serialized_end=996
  _EVENTVALSETCONFIRM._serialized_start=998
  _EVENTVALSETCONFIRM._serialized_end=1070
  _EVENTSENDTOETH._serialized_start=1073
  _EVENTSENDTOETH._serialized_end=1281
  _EVENTCONFIRMBATCH._serialized_start=1283
  _EVENTCONFIRMBATCH._serialized_end=1353
  _EVENTATTESTATIONVOTE._serialized_start=1355
  _EVENTATTESTATIONVOTE._serialized_end=1437
  _EVENTDEPOSITCLAIM._serialized_start=1440
  _EVENTDEPOSITCLAIM._serialized_end=1708
  _EVENTWITHDRAWCLAIM._serialized_start=1711
  _EVENTWITHDRAWCLAIM._serialized_end=1873
  _EVENTERC20DEPLOYEDCLAIM._serialized_start=1876
  _EVENTERC20DEPLOYEDCLAIM._serialized_end=2092
  _EVENTVALSETUPDATECLAIM._serialized_start=2095
  _EVENTVALSETUPDATECLAIM._serialized_end=2392
  _EVENTCANCELSENDTOETH._serialized_start=2394
  _EVENTCANCELSENDTOETH._serialized_end=2440
  _EVENTSUBMITBADSIGNATUREEVIDENCE._serialized_start=2442
  _EVENTSUBMITBADSIGNATUREEVIDENCE._serialized_end=2537
# @@protoc_insertion_point(module_scope)
