# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/auction/v1beta1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from injective.auction.v1beta1 import auction_pb2 as injective_dot_auction_dot_v1beta1_dot_auction__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'injective/auction/v1beta1/genesis.proto\x12\x19injective.auction.v1beta1\x1a\'injective/auction/v1beta1/auction.proto\x1a\x14gogoproto/gogo.proto\"\xb5\x01\n\x0cGenesisState\x12\x37\n\x06params\x18\x01 \x01(\x0b\x32!.injective.auction.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x12\x15\n\rauction_round\x18\x02 \x01(\x04\x12\x33\n\x0bhighest_bid\x18\x03 \x01(\x0b\x32\x1e.injective.auction.v1beta1.Bid\x12 \n\x18\x61uction_ending_timestamp\x18\x04 \x01(\x03\x42OZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.auction.v1beta1.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZMgithub.com/InjectiveLabs/injective-core/injective-chain/modules/auction/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=134
  _GENESISSTATE._serialized_end=315
# @@protoc_insertion_point(module_scope)
