# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/attestation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$injective/peggy/v1/attestation.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\"c\n\x0b\x41ttestation\x12\x10\n\x08observed\x18\x01 \x01(\x08\x12\r\n\x05votes\x18\x02 \x03(\t\x12\x0e\n\x06height\x18\x03 \x01(\x04\x12#\n\x05\x63laim\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"^\n\nERC20Token\x12\x10\n\x08\x63ontract\x18\x01 \x01(\t\x12>\n\x06\x61mount\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Int\xc8\xde\x1f\x00*\x9f\x02\n\tClaimType\x12.\n\x12\x43LAIM_TYPE_UNKNOWN\x10\x00\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_UNKNOWN\x12.\n\x12\x43LAIM_TYPE_DEPOSIT\x10\x01\x1a\x16\x8a\x9d \x12\x43LAIM_TYPE_DEPOSIT\x12\x30\n\x13\x43LAIM_TYPE_WITHDRAW\x10\x02\x1a\x17\x8a\x9d \x13\x43LAIM_TYPE_WITHDRAW\x12<\n\x19\x43LAIM_TYPE_ERC20_DEPLOYED\x10\x03\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_ERC20_DEPLOYED\x12<\n\x19\x43LAIM_TYPE_VALSET_UPDATED\x10\x04\x1a\x1d\x8a\x9d \x19\x43LAIM_TYPE_VALSET_UPDATED\x1a\x04\x88\xa3\x1e\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.attestation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types'
  _CLAIMTYPE._options = None
  _CLAIMTYPE._serialized_options = b'\210\243\036\000'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_UNKNOWN"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_UNKNOWN"]._serialized_options = b'\212\235 \022CLAIM_TYPE_UNKNOWN'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_DEPOSIT"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_DEPOSIT"]._serialized_options = b'\212\235 \022CLAIM_TYPE_DEPOSIT'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_WITHDRAW"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_WITHDRAW"]._serialized_options = b'\212\235 \023CLAIM_TYPE_WITHDRAW'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_ERC20_DEPLOYED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_ERC20_DEPLOYED'
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._options = None
  _CLAIMTYPE.values_by_name["CLAIM_TYPE_VALSET_UPDATED"]._serialized_options = b'\212\235 \031CLAIM_TYPE_VALSET_UPDATED'
  _ERC20TOKEN.fields_by_name['amount']._options = None
  _ERC20TOKEN.fields_by_name['amount']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Int\310\336\037\000'
  _CLAIMTYPE._serialized_start=307
  _CLAIMTYPE._serialized_end=594
  _ATTESTATION._serialized_start=109
  _ATTESTATION._serialized_end=208
  _ERC20TOKEN._serialized_start=210
  _ERC20TOKEN._serialized_end=304
# @@protoc_insertion_point(module_scope)
