# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/wasmx/v1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1binjective/wasmx/v1/tx.proto\x12\x12injective.wasmx.v1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"X\n\x18MsgExecuteContractCompat\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x10\n\x08\x63ontract\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05\x66unds\x18\x04 \x01(\t\"0\n MsgExecuteContractCompatResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x80\x01\n\x11MsgUpdateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\x12\x11\n\tgas_limit\x18\x03 \x01(\x04\x12\x11\n\tgas_price\x18\x04 \x01(\x04\x12\x1b\n\radmin_address\x18\x05 \x01(\tB\x04\xc8\xde\x1f\x01\"\x1b\n\x19MsgUpdateContractResponse\"?\n\x13MsgActivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"\x1d\n\x1bMsgActivateContractResponse\"A\n\x15MsgDeactivateContract\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x18\n\x10\x63ontract_address\x18\x02 \x01(\t\"\x1f\n\x1dMsgDeactivateContractResponse2\xea\x03\n\x03Msg\x12t\n\x1cUpdateRegistryContractParams\x12%.injective.wasmx.v1.MsgUpdateContract\x1a-.injective.wasmx.v1.MsgUpdateContractResponse\x12t\n\x18\x41\x63tivateRegistryContract\x12\'.injective.wasmx.v1.MsgActivateContract\x1a/.injective.wasmx.v1.MsgActivateContractResponse\x12z\n\x1a\x44\x65\x61\x63tivateRegistryContract\x12).injective.wasmx.v1.MsgDeactivateContract\x1a\x31.injective.wasmx.v1.MsgDeactivateContractResponse\x12{\n\x15\x45xecuteContractCompat\x12,.injective.wasmx.v1.MsgExecuteContractCompat\x1a\x34.injective.wasmx.v1.MsgExecuteContractCompatResponseBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.wasmx.v1.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/wasmx/types'
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._options = None
  _MSGUPDATECONTRACT.fields_by_name['admin_address']._serialized_options = b'\310\336\037\001'
  _MSGEXECUTECONTRACTCOMPAT._serialized_start=127
  _MSGEXECUTECONTRACTCOMPAT._serialized_end=215
  _MSGEXECUTECONTRACTCOMPATRESPONSE._serialized_start=217
  _MSGEXECUTECONTRACTCOMPATRESPONSE._serialized_end=265
  _MSGUPDATECONTRACT._serialized_start=268
  _MSGUPDATECONTRACT._serialized_end=396
  _MSGUPDATECONTRACTRESPONSE._serialized_start=398
  _MSGUPDATECONTRACTRESPONSE._serialized_end=425
  _MSGACTIVATECONTRACT._serialized_start=427
  _MSGACTIVATECONTRACT._serialized_end=490
  _MSGACTIVATECONTRACTRESPONSE._serialized_start=492
  _MSGACTIVATECONTRACTRESPONSE._serialized_end=521
  _MSGDEACTIVATECONTRACT._serialized_start=523
  _MSGDEACTIVATECONTRACT._serialized_end=588
  _MSGDEACTIVATECONTRACTRESPONSE._serialized_start=590
  _MSGDEACTIVATECONTRACTRESPONSE._serialized_end=621
  _MSG._serialized_start=624
  _MSG._serialized_end=1114
# @@protoc_insertion_point(module_scope)
