# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/crypto/v1beta1/ethsecp256k1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0injective/crypto/v1beta1/ethsecp256k1/keys.proto\x12%injective.crypto.v1beta1.ethsecp256k1\x1a\x14gogoproto/gogo.proto\"\x1b\n\x06PubKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:\x04\x98\xa0\x1f\x00\"\x16\n\x07PrivKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.crypto.v1beta1.ethsecp256k1.keys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/crypto/ethsecp256k1'
  _PUBKEY._options = None
  _PUBKEY._serialized_options = b'\230\240\037\000'
  _PUBKEY._serialized_start=113
  _PUBKEY._serialized_end=140
  _PRIVKEY._serialized_start=142
  _PRIVKEY._serialized_end=164
# @@protoc_insertion_point(module_scope)
